@@ -1,6 +1,5 @@
 #' Check species status (native, exotic, ...) for one species from Flora Europaea webpage
 #'
-#' @importFrom XML xmlValue getNodeSet htmlTreeParse
 #' @export
 #'
 #' @param sp character; a vector of length one with a single scientific species names in
@@ -33,6 +32,8 @@
 #'
 
 fe_native <- function(sp, ...) {
+  .Deprecated(msg = "fe_native is deprecated - see flora_europaea() function in originr")
+
   #reformat sp list
   genus <- strsplit(sp, " ")[[1]][1]
   species <- strsplit(sp, " ")[[1]][2]
@@ -42,62 +43,65 @@ fe_native <- function(sp, ...) {
                SPECIES_XREF = species, TAXON_NAME_XREF = "", RANK = "")
   message(paste("Checking species", sp))
   #Parse url and extract table
-  #readHTMLTable(urls) #Not working, don't know why.
   url_check <- GET(url, query = args, ...)
   warn_for_status(url_check)
-  doc <- htmlTreeParse(content(url_check, "text"), useInternalNodes = TRUE, encoding = "UTF-8")
-  tables <- getNodeSet(doc, "//table")
+  doc <- xml2::read_html(content(url_check, "text", encoding = "UTF-8"), encoding = "UTF-8")
+  tables <- xml2::xml_find_all(doc, "//table")
+
   if (length(tables) < 3) {
     message("Species not found")
   } else {
-    #t <- readHTMLTable(tables[[3]]) #Not working either
     #try alternative
     # I am assuming 3 is always right, so far it is.
     ### Scott here: would be better to select the table by name if possible
-    text <- xmlValue(tables[[3]], trim = FALSE)
-    m_nat <- regexpr("Distribution: [A-Za-z ()?*%,]*", text, perl = TRUE)
-    distr_nat <- regmatches(text, m_nat)
-    distr_status <- regmatches(distr_nat,
+    text <- xml_text(tables[[3]], trim = FALSE)
+    if (!grepl("Distribution:", text, perl = TRUE)) {
+      message("Species with no distribution. Probably not native.")
+    } else{
+      m_nat <- regexpr("Distribution: [A-Za-z ()?*%,]*", text, perl = TRUE)
+      distr_nat <- regmatches(text, m_nat)
+      distr_status <- regmatches(distr_nat,
                                gregexpr("[*][A-Z][a-z]", distr_nat, perl = TRUE)) # * Status doubtful; possibly native
-    distr_occ <- regmatches(distr_nat,
+      distr_occ <- regmatches(distr_nat,
                             gregexpr("[?][A-Z][a-z]", distr_nat, perl = TRUE)) # ? Occurrence doubtful
-    distr_ext <- regmatches(distr_nat,
+      distr_ext <- regmatches(distr_nat,
                             gregexpr("[%][A-Z][a-z]", distr_nat, perl = TRUE)) # % Extinct
-    #also deal with Rs(N) extract e.g. Rs(N,B,C,W,K,E)
-    distr_nat <- gsub(",", " ", distr_nat)
-    distr_nat <- gsub("(", " ", distr_nat, fixed = TRUE)
-    distr_nat <- gsub(")", "", distr_nat, fixed = TRUE)
-    distr_nat <- gsub("Distribution: ", "", distr_nat)
+      #also deal with Rs(N) extract e.g. Rs(N,B,C,W,K,E)
+      distr_nat <- gsub(",", " ", distr_nat)
+      distr_nat <- gsub("(", " ", distr_nat, fixed = TRUE)
+      distr_nat <- gsub(")", "", distr_nat, fixed = TRUE)
+      distr_nat <- gsub("Distribution: ", "", distr_nat)
 
-    nat = exo = stat = oc = ex = NA
-    if (distr_nat != "") {
-      native <- strsplit(distr_nat, " ")[[1]]
-      delete <- which(!native %in% country$short)
-      if (length(delete) > 0) native <- native[-delete]
-      nat <- sapply(native, function(x) {country[which(x == country$short), "long"]})
-    }
-    if (length(distr_status[[1]]) > 0) {
-      status <- gsub("*", "", distr_status[[1]], fixed = TRUE)
-      stat <- sapply(status, function(x) {country[which(x == country$short), "long"]})
-    }
-    if (length(distr_occ[[1]]) > 0) {
-      occ <- gsub("?", "", distr_occ[[1]], fixed = TRUE)
-      oc <- sapply(occ, function(x) {country[which(x == country$short), "long"]})
-    }
-    if (length(distr_ext[[1]]) > 0) {
-      ext <- gsub("%", "", distr_ext[[1]], fixed = TRUE)
-      ex <- sapply(ext, function(x) {country[which(x == country$short), "long"]})
-    }
-    #extract exotics
-    m_ex <- regexpr("[[][A-Za-z ()?*%,]*", text, perl = TRUE)
-    distr_exot <- regmatches(text, m_ex)
-    if (length(distr_exot) > 0) {
-      #NEED TO ADD * ? % for exotics? I don't think those cases exist. Maybe ?
-      exotic <- strsplit(gsub("[", "", distr_exot, fixed = TRUE), " ")[[1]]
-      exo <- sapply(exotic, function(x) {country[which(x == country$short), "long"]})
-    }
-    list(native = as.character(nat), exotic = as.character(exo), status_doubtful = as.character(stat),
+      nat = exo = stat = oc = ex = NA
+      if (distr_nat != "") {
+        native <- strsplit(distr_nat, " ")[[1]]
+        delete <- which(!native %in% country$short)
+        if (length(delete) > 0) native <- native[-delete]
+        nat <- sapply(native, function(x) {country[which(x == country$short), "long"]})
+      }
+      if (length(distr_status[[1]]) > 0) {
+        status <- gsub("*", "", distr_status[[1]], fixed = TRUE)
+        stat <- sapply(status, function(x) {country[which(x == country$short), "long"]})
+      }
+      if (length(distr_occ[[1]]) > 0) {
+        occ <- gsub("?", "", distr_occ[[1]], fixed = TRUE)
+        oc <- sapply(occ, function(x) {country[which(x == country$short), "long"]})
+      }
+      if (length(distr_ext[[1]]) > 0) {
+        ext <- gsub("%", "", distr_ext[[1]], fixed = TRUE)
+        ex <- sapply(ext, function(x) {country[which(x == country$short), "long"]})
+      }
+      #extract exotics
+      m_ex <- regexpr("[[][A-Za-z ()?*%,]*", text, perl = TRUE)
+      distr_exot <- regmatches(text, m_ex)
+      if (length(distr_exot) > 0) {
+        #NEED TO ADD * ? % for exotics? I don't think those cases exist. Maybe ?
+        exotic <- strsplit(gsub("[", "", distr_exot, fixed = TRUE), " ")[[1]]
+        exo <- sapply(exotic, function(x) {country[which(x == country$short), "long"]})
+      }
+      list(native = as.character(nat), exotic = as.character(exo), status_doubtful = as.character(stat),
          occurrence_doubtful = as.character(oc), extinct = as.character(ex))
+    }
   }
 }
 
