@@ -1,6 +1,5 @@
 #' Check invasive species status for a set of species from GISD database
 #'
-#' @importFrom XML xmlValue getNodeSet htmlTreeParse
 #' @export
 #'
 #' @param x character; a vector of scientific species names in the form of
@@ -42,8 +41,9 @@
 #' }
 #'
 
-g_invasive <- function(x, simplify = FALSE, verbose=TRUE)
-{
+g_invasive <- function(x, simplify = FALSE, verbose=TRUE) {
+  .Deprecated(msg = "g_invasive is deprecated - see gisd() function in originr")
+
 	species <- gsub(" ", "+", x) # reformat sp list
 	# create urls to parse
 	urls <- paste("http://www.issg.org/database/species/search.asp?sts=sss&st=sss&fr=1&x=13&y=9&sn=",
@@ -51,17 +51,17 @@ g_invasive <- function(x, simplify = FALSE, verbose=TRUE)
 	# create a data.frame to store the Output
 	out <- data.frame(species = x, status = c(1:length(urls)))
 	#loop through all species
-	for(i in seq_along(urls)){
+	for (i in seq_along(urls)) {
 		#Parse url and extract table
-		doc <- htmlTreeParse(urls[i], useInternalNodes = TRUE)
-		if(length(getNodeSet(doc, "//span[@class='SearchTitle']")) > 0){
+		doc <- xml2::read_html(urls[i])
+		if (length(xml2::xml_find_all(doc, "//span[@class='SearchTitle']")) > 0) {
 			out[i, 2] <- "Not in GISD"
 		} else{
-			if(!simplify){
-			  one <- tryCatch(getNodeSet(doc, "//span[@class='ListNote']", fun=xmlValue)[[1]],
+			if (!simplify) {
+			  one <- tryCatch(xml2::xml_text(xml2::xml_find_all(doc, "//span[@class='ListNote']"))[[1]],
                         error = function(e) e)
-			  two <- paste(getNodeSet(doc, "//span[@class='Info']", fun=xmlValue), collapse="; ")
-			  out[i, 2] <- paste(if(is(one, "simpleError")) NULL else one, two, sep="; ")
+			  two <- paste(xml2::xml_text(xml2::xml_find_all(doc, "//span[@class='Info']")), collapse = "; ")
+			  out[i, 2] <- paste(if (is(one, "simpleError")) NULL else one, two, sep = "; ")
 			} else {
         out[i, 2] <- "Invasive"
 			}
