@@ -1,6 +1,5 @@
 #' Check if a species is native somewhere
 #'
-#' @importFrom taxize get_tsn itis_native
 #' @export
 #'
 #' @param sp character; a vector of length one with a single scientific species
@@ -19,16 +18,15 @@
 #' "USSR_Baltic_Division", "USSR_Central_Division", "USSR_South_western", "USSR_Krym",
 #' "USSRSouth_eastern_Division"
 #' @param ... Curl options passed on to \code{\link[httr]{GET}}
-#' @return A vectors saying if is native or exotic. When species is not found in the
-#' database its indicated.
+#' @return A data.frame, with species name and result of origin check
 #'
 #' @description This function check the status (native or exotic) of a species in a
 #' given place
 #'
-#' For that end, calls itis_native{taxize} and fe_native{traits}. See help
-#' documentation of those functions for details.
+#' For that end, calls \code{\link[taxize]{itis_native}} and \code{\link{fe_native}}.
+#' See help documentation of those functions for details.
 #'
-#' So many more things can be done, like checking species first with taxize, adding
+#' So many more things can be done, like checking species first with \pkg{taxize}, adding
 #' more native lists to check...
 #'
 #' @author Ignasi Bartomeus \email{nacho.bartomeus@@gmail.com}
@@ -36,21 +34,28 @@
 #' sp <- c("Lavandula stoechas", "Carpobrotus edulis", "Rhododendron ponticum",
 #'        "Alkanna lutea", "Anchusa arvensis")
 #' is_native(sp[1], where = "Islas_Baleares", region = "europe")
-#' sapply(sp, is_native, where = "Continental US", region = "america")
-#' sapply(sp, is_native, where = "Islas_Baleares", region = "europe")
+#' lapply(sp, is_native, where = "Continental US", region = "america")
+#' lapply(sp, is_native, where = "Islas_Baleares", region = "europe")
+#'
+#' # combine output for many taxa
+#' res <- lapply(sp, is_native, where = "Continental US", region = "america")
+#' library("dplyr")
+#' rbind_all(res)
 #' }
 is_native <- function(sp, where, region = c("america", "europe"), ...) {
+  .Deprecated(msg = "is_native is deprecated - see is_native() function in originr")
+
   if (!region %in% c("america", "europe")) {
-    stop("region must be one of america or europe")
+    stop("region must be one of america or europe", call. = FALSE)
   }
   if (length(sp) > 1) {
-    stop("sp should be a single species")
+    stop("sp should be a single species", call. = FALSE)
   }
   if (region == "america") {
     if (!where %in% c("Continental US", "Alaska", "Canada",
-                     "Caribbean Territories", "Central Pacific Territories",
-                     "Hawaii", "Mexico")) {
-      stop("where must be one America region, see help for accepted names")
+                      "Caribbean Territories", "Central Pacific Territories",
+                      "Hawaii", "Mexico")) {
+      stop("where must be one America region, see help for accepted names", call. = FALSE)
     }
     tsn_ <- get_tsn(searchterm = sp, ...)[1]
     if (is.na(tsn_)) {
@@ -62,24 +67,24 @@ is_native <- function(sp, where, region = c("america", "europe"), ...) {
   }
   if (region == "europe") {
     if (!where %in% c("Albania", "Austria", "Azores", "Belgium", "Islas_Baleares",
-                     "Britain", "Bulgaria", "Corse", "Kriti",
-                     "Czechoslovakia", "Denmark", "Faroer",
-                     "Finland", "France", "Germany", "Greece",
-                     "Ireland", "Switzerland", "Netherlands", "Spain",
-                     "Hungary", "Iceland", "Italy", "Jugoslavia",
-                     "Portugal", "Norway", "Poland", "Romania",
-                     "USSR", "Sardegna", "Svalbard", "Sicilia",
-                     "Sweden", "Turkey", "USSR_Northern_Division",
-                     "USSR_Baltic_Division", "USSR_Central_Division",
-                     "USSR_South_western", "USSR_Krym",
-                     "USSRSouth_eastern_Division")) {
-      stop("where must be one eu country, see help for accepted names")
+                      "Britain", "Bulgaria", "Corse", "Kriti",
+                      "Czechoslovakia", "Denmark", "Faroer",
+                      "Finland", "France", "Germany", "Greece",
+                      "Ireland", "Switzerland", "Netherlands", "Spain",
+                      "Hungary", "Iceland", "Italy", "Jugoslavia",
+                      "Portugal", "Norway", "Poland", "Romania",
+                      "USSR", "Sardegna", "Svalbard", "Sicilia",
+                      "Sweden", "Turkey", "USSR_Northern_Division",
+                      "USSR_Baltic_Division", "USSR_Central_Division",
+                      "USSR_South_western", "USSR_Krym",
+                      "USSRSouth_eastern_Division")) {
+      stop("where must be one eu country, see help for accepted names", call. = FALSE)
     }
     origin <- fe_native(sp)
     if (length(origin) < 5) {
       Out <- "Species not in flora europaea"
     } else {
-      Out <- "Not found"
+      Out <- "Species not present in your selected region"
       if (where %in% origin$native) {
         Out <- "Native"
       }
@@ -91,5 +96,5 @@ is_native <- function(sp, where, region = c("america", "europe"), ...) {
       }
     }
   }
-  Out
+  data.frame(name = sp, origin = Out, stringsAsFactors = FALSE)
 }
