@@ -18,10 +18,9 @@
 #' species <- c("Colletes similis","Halictus ligatus","Perdita trisignata")
 #' ncbi_byname(taxa=species, gene = c("coi", "co1"), seqrange = "1:2000")
 #' }
-ncbi_byname <- function(taxa, gene="COI", seqrange="1:3000", getrelated=FALSE, verbose=TRUE)
-{
-  foo <- function(xx){
-    mssg(verbose, paste("Working on ", xx, "...", sep=""))
+ncbi_byname <- function(taxa, gene="COI", seqrange="1:3000", getrelated=FALSE, verbose=TRUE) {
+  foo <- function(xx) {
+    mssg(verbose, paste("Working on ", xx, "...", sep = ""))
     mssg(verbose, "...retrieving sequence IDs...")
 
     if (length(gene) > 1) {
@@ -35,9 +34,9 @@ ncbi_byname <- function(taxa, gene="COI", seqrange="1:3000", getrelated=FALSE, v
                                                seqrange, "[SLEN]", collapse = " "), RetMax = 500)
 
     out <-
-      xpathApply(content(GET("http://eutils.ncbi.nlm.nih.gov/entrez/eutils/esearch.fcgi",
-                             query = query), "parsed"), "//eSearchResult")[[1]]
-    if (as.numeric(xmlValue(xpathApply(out, "//Count")[[1]])) == 0) {
+      xml2::xml_find_all(xml2::read_xml(content(GET("http://eutils.ncbi.nlm.nih.gov/entrez/eutils/esearch.fcgi",
+                             query = query), "text", encoding = "UTF-8")), "//eSearchResult")[[1]]
+    if (as.numeric(xml2::xml_text(xml2::xml_find_all(out, "//Count")[[1]])) == 0) {
       message(paste("no sequences of ", gene, " for ", xx, " - getting other sp.", sep = ""))
       if (getrelated == FALSE) {
         mssg(verbose, paste("no sequences of ", gene, " for ", xx, sep = ""))
@@ -46,30 +45,31 @@ ncbi_byname <- function(taxa, gene="COI", seqrange="1:3000", getrelated=FALSE, v
       } else {
         mssg(verbose, "...retrieving sequence IDs for related species...")
         newname <- strsplit(xx, " ")[[1]][[1]]
-        query <- list(db = "nuccore", term = paste(newname, "[Organism] AND", genes_, "AND", seqrange, "[SLEN]", collapse=" "), RetMax=500)
+        query <- list(db = "nuccore", term = paste(newname, "[Organism] AND", genes_, "AND", seqrange, "[SLEN]", collapse = " "), RetMax = 500)
         out <-
-          xpathApply(content(GET("http://eutils.ncbi.nlm.nih.gov/entrez/eutils/esearch.fcgi", query=query), "parsed"), "//eSearchResult")[[1]]
-        if( as.numeric(xmlValue(xpathApply(out, "//Count")[[1]]))==0 ){
-          mssg(verbose, paste("no sequences of ", gene, " for ", xx, " or ", newname, sep=""))
+          xml2::xml_find_all(xml2::read_xml(content(GET("http://eutils.ncbi.nlm.nih.gov/entrez/eutils/esearch.fcgi", query = query),
+                                                    "text", encoding = "UTF-8")), "//eSearchResult")[[1]]
+        if (as.numeric(xml2::xml_text(xml2::xml_find_all(out, "//Count")[[1]])) == 0) {
+          mssg(verbose, paste("no sequences of ", gene, " for ", xx, " or ", newname, sep = ""))
           res <- data.frame(list(xx, "NA", "NA", "NA", "NA", "NA", "NA"))
           names(res) <- NULL
-        } else
-        {
+        } else {
           ## For each species = get GI number with longest sequence
           mssg(verbose, "...retrieving sequence ID with longest sequence length...")
-          querysum <- list(db = "nucleotide", id = paste(make_ids(out), collapse=" ")) # construct query for species
+          querysum <- list(db = "nucleotide", id = paste(make_ids(out), collapse = " ")) # construct query for species
           res <- parse_ncbi(xx,
-            xpathApply(content(GET("http://eutils.ncbi.nlm.nih.gov/entrez/eutils/esummary.fcgi",
-                                   query=querysum), "parsed"), "//eSummaryResult")[[1]], verbose)
+                xml2::xml_find_all(
+                  xml2::read_xml(content(GET("http://eutils.ncbi.nlm.nih.gov/entrez/eutils/esummary.fcgi",
+                                   query = querysum), "text", encoding = "UTF-8")), "//eSummaryResult"), verbose)
         }
       }
     } else {
       ## For each species = get GI number with longest sequence
       mssg(verbose, "...retrieving sequence ID with longest sequence length...")
       querysum <- list(db = "nucleotide", id = paste(make_ids(out), collapse = " ")) # construct query for species
-      res <- parse_ncbi(xx, xpathApply(content( # API call
+      res <- parse_ncbi(xx, xml2::xml_find_all(xml2::read_xml(content( # API call
         GET("http://eutils.ncbi.nlm.nih.gov/entrez/eutils/esummary.fcgi",
-            query = querysum), "parsed"), "//eSummaryResult")[[1]], verbose)
+            query = querysum), "text", encoding = "UTF-8")), "//eSummaryResult")[[1]], verbose)
     }
 
     mssg(verbose, "...done.")
@@ -77,33 +77,34 @@ ncbi_byname <- function(taxa, gene="COI", seqrange="1:3000", getrelated=FALSE, v
   }
 
   foo_safe <- tryfail(NULL, foo)
-  if(length(taxa)==1){ foo_safe(taxa) } else { lapply(taxa, foo_safe) }
+  if (length(taxa) == 1){ foo_safe(taxa) } else { lapply(taxa, foo_safe) }
 }
 
 parse_ncbi <- function(xx, z, verbose){
-  names <- sapply(getNodeSet(z[[1]], "//Item"), xmlGetAttr, name="Name") # gets names of values in summary
-  prd <- as.character(sapply(getNodeSet(z, "//Item"), xmlValue)[grepl("Caption", names)]) #  get access numbers
+  names <- xml2::xml_attr(xml2::xml_find_all(z, "//Item"), "Name") # gets names of values in summary
+  prd <- xml2::xml_text(xml2::xml_find_all(z, '//Item[@Name="Caption"]')) #  get access numbers
   prd <- sapply(prd, function(x) strsplit(x, "_")[[1]][[1]], USE.NAMES=FALSE)
-  l_ <- as.numeric(sapply(getNodeSet(z, "//Item"), xmlValue)[grepl("Length", names)]) # gets seq lengths
-  gis <- as.numeric(sapply(getNodeSet(z, "//Item"), xmlValue)[grepl("Gi", names)]) # gets GI numbers
-  sns <- sapply(getNodeSet(z, "//Item"), xmlValue)[grepl("Title", names)] # gets seq lengths # get spp names
+  l_ <- as.numeric(xml2::xml_text(xml2::xml_find_all(z, '//Item[@Name="Length"]'))) # gets seq lengths
+  gis <- as.numeric(xml2::xml_text(xml2::xml_find_all(z, '//Item[@Name="Gi"]'))) # gets GI numbers
+  sns <- xml2::xml_text(xml2::xml_find_all(z, '//Item[@Name="Title"]')) # gets seq lengths # get spp names
   df <- data.frame(gis=gis, length=l_, spnames=sns, predicted=prd, stringsAsFactors = FALSE)
   df <- df[!df$predicted %in% c("XM","XR"),] # remove predicted sequences
   gisuse <- df[which.max(x=df$length),] # picks longest sequnence length
-  if(nrow(gisuse) > 1){ gisuse <- gisuse[sample(nrow(gisuse), 1), ] } else { gisuse <- gisuse }
-
+  if (NROW(gisuse) > 1) {
+    gisuse <- gisuse[sample(NROW(gisuse), 1), ]
+  }
   ## Get sequence from previous
   mssg(verbose, "...retrieving sequence...")
   queryseq <- list(db = "sequences", id = gisuse[,1], rettype = "fasta", retmode = "text")
-  outseq <- content(GET("http://eutils.ncbi.nlm.nih.gov/entrez/eutils/efetch.fcgi", query = queryseq), as="text")
+  outseq <- content(GET("http://eutils.ncbi.nlm.nih.gov/entrez/eutils/efetch.fcgi", query = queryseq), "text", encoding = "UTF-8")
   seq <- gsub("\n", "", strsplit(sub("\n", "<<<", outseq), "<<<")[[1]][[2]])
   accessnum <- strsplit(outseq, "\\|")[[1]][4]
   outt <- list(xx, as.character(gisuse[,3]), gisuse[,1], accessnum, gisuse[,2], seq)
 
-  spused <- paste(strsplit(outt[[2]], " ")[[1]][1:2], sep="", collapse=" ")
-  outoutout <- data.frame(outt, spused=spused, stringsAsFactors = FALSE)
+  spused <- paste(strsplit(outt[[2]], " ")[[1]][1:2], sep = "", collapse = " ")
+  outoutout <- data.frame(outt, spused = spused, stringsAsFactors = FALSE)
   names(outoutout) <- NULL
   outoutout
 }
 
-make_ids <- function(x) as.numeric(sapply(xpathApply(x, "//IdList//Id"), xmlValue))
+make_ids <- function(x) as.numeric(xml2::xml_text(xml2::xml_find_all(x, "//IdList//Id")))
